public class JMSTopicClient implements MessageListener, ExceptionListener {
	
	public void subscribe() throws NamingException, JMSException {
		Properties props = new Properties();
		props.put(Context.PROVIDER_URL, PROVIDER_URL);
		props.put(Context.INITIAL_CONTEXT_FACTORY, CONTEXT_FACTORY);
		InitialContext ctx = new InitialContext(props);
		TopicConnectionFactory tcf = (TopicConnectionFactory) ctx
				.lookup(CONNECTION_FACTORY);

		conn = tcf.createTopicConnection();
		String hostname = getHostName();
		if (hostname == null) {

			logger.warn("Couldn't determine the hostname from the network "
					+ "subsystem, or from the system properties. Using an "
					+ "anonymous client ID.");

		} else {
			String clientId = "workstation-" + hostname;
			conn.setClientID(clientId);
		}
		topic = (Topic) ctx.lookup(TOPIC_NAME);
		session = conn.createTopicSession(false, TopicSession.AUTO_ACKNOWLEDGE);
		recv = session.createSubscriber(topic);
		recv.setMessageListener(this);
		conn.setExceptionListener(this);
		conn.start();
	}

	public static void main(String[] args) {

	       JMSTopicClient client = new JMSTopicClient("/cyrus/CyrusConnectionFactory",
				"/topic/CyrusWorkstationTopic", "uktapp02.tui.de:1099",
				"org.jnp.interfaces.NamingContextFactory") {
			@Override
			public void onMessage(Message msg) {
				try {
					super.onMessage(msg);
					String message = ((TextMessage) msg).getText();
					if ("EXIT".equals(message)) {
						System.out.println("Exiting Listener Client.");
						this.disconnect();
					}
				} catch (JMSException ex) {
					ex.printStackTrace();
					logger.error("onMessage(): ", ex);
				}
			}
		};

		try {
			
			if ((args.length == 1) && "-listen".equals(args[0])) {
				System.out.println("Starting Listener On: " + client.TOPIC_NAME);
				client.subscribe();
			} 
		} catch (Exception ex) {
			ex.printStackTrace();
		}

}

	public JMSTopicClient(String connectionFactoryName, String topicName,
			String providerURL, String contextFactory) {
		this.CONNECTION_FACTORY = connectionFactoryName;
		this.TOPIC_NAME = topicName;
		this.PROVIDER_URL = providerURL;
		this.CONTEXT_FACTORY = contextFactory;
	}
}